@@ -1,7 +1,7 @@
 package Sah::Schema::perl::modname;
 
-our $DATE = '2016-08-03'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2017-01-31'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module name',
@@ -9,6 +9,10 @@ our $schema = [str => {
     'x.perl.coerce_rules' => [
         'str_normalize_perl_modname',
     ],
+
+    # provide a default completion which is from list of installed perl modules
+    'x.completion' => 'perl_modname',
+
 }, {}];
 
 1;
@@ -26,7 +30,7 @@ Sah::Schema::perl::modname - Perl module name
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::perl::modname (from Perl distribution Sah-Schemas-Perl), released on 2016-08-03.
+This document describes version 0.007 of Sah::Schema::perl::modname (from Perl distribution Sah-Schemas-Perl), released on 2017-01-31.
 
 =head1 HOMEPAGE
 
@@ -50,7 +54,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
